@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.2.1 Debian package creator
-# Release 2020-04-21
+# DaVinci Resolve 16.2 Debian package creator
+# Release 2020-03-06
 # By Daniel Tufvesson
 #
 
@@ -27,8 +27,16 @@ copy_object() {
 }
 
 link_object() {
-    echo "[LINK] $2 [TO] $1"
-    ln -s "$1" "$2"
+    if [ -e "$1" ] ; then
+	echo "[LINK] $2 [TO] $1"
+	ln -s "$1" "$2"
+	if [ $? -ne 0 ] ; then
+	    ERRORS=$((ERRORS+1))
+	fi
+    else
+	echo "[ERROR: MISSING] $1"
+	ERRORS=$((ERRORS+1))
+    fi
 }
 
 create_directory() {
@@ -62,8 +70,8 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.2.1
-DEB_STEPPING=1
+RESOLVE_VERSION=16.2
+DEB_STEPPING=2
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
